
# The problem

No serious attempt has been made to make it deployable for users.


# The solution

Proper Python / github procedures for deploying the code and making it easy to use.

# Considerations

- pypi
- readthedocs

Both of above as done by the NWS guy.

# Learning required

- Python / github deployment procedures
- relevant sites eg, pypi, readthedocs


# Tradeoffs

All upside




